@@ -1,5 +1,5 @@
 /*
- * Copyright © 2007,2008 daniel g. siegel <dgsiegel@gmail.com>
+ * Copyright © 2007-2009 daniel g. siegel <dgsiegel@gnome.org>
  * Copyright © 2007,2008 Jaap Haitsma <jaap@haitsma.org>
  * Copyright © 2008 Felix Kaser <f.kaser@gmx.net>
  *
@@ -28,6 +28,7 @@
 #include <gio/gio.h>
 #include <gtk/gtk.h>
 #include <gst/gst.h>
+#include <librsvg/rsvg.h>
 
 #include "cheese-fileutil.h"
 #include "cheese-window.h"
@@ -37,7 +38,6 @@ struct _CheeseOptions
 {
   gboolean verbose;
   gboolean wide_mode;
-  char *hal_device_id;
   gboolean version;
 } CheeseOptions;
 
@@ -85,72 +85,6 @@ cheese_print_handler (char *string)
     fputs (string, fp);
 }
 
-void
-cheese_handle_files_from_before_224 (void)
-{
-  CheeseFileUtil *fileutil             = cheese_fileutil_new ();
-  gchar          *photo_path           = cheese_fileutil_get_photo_path (fileutil);
-  gchar          *video_path           = cheese_fileutil_get_video_path (fileutil);
-  gchar          *path_from_before_224 = cheese_fileutil_get_path_before_224 (fileutil);
-  GDir           *dir_from_before_224;
-  gchar          *source_filename, *target_filename;
-  const char     *name;
-  GFile          *source, *target, *dir;
-
-  if (g_file_test (path_from_before_224, G_FILE_TEST_IS_DIR) &&
-      (g_strcmp0 (video_path, path_from_before_224) != 0) &&
-      (g_strcmp0 (photo_path, path_from_before_224) != 0))
-  {
-    dir_from_before_224 = g_dir_open (path_from_before_224, 0, NULL);
-
-    while ((name = g_dir_read_name (dir_from_before_224)))
-    {
-      /* the filenames from before 2.24 have different namings than the > 2.24
-       * files (0042.jpg/ogg vs. 2008-09-09-015555.jpg/ogv) so we just copy and
-       * rename the ogg files to ogv
-       */
-      if (g_str_has_suffix (name, VIDEO_NAME_SUFFIX))
-      {
-        target_filename = g_build_filename (video_path, name, NULL);
-      }
-      else if (g_str_has_suffix (name, ".ogg"))
-      {
-        gchar *filename  = g_strdup (name);
-        gchar *extension = g_strrstr (filename, ".ogg");
-        extension[3]    = 'v';
-        target_filename = g_build_filename (video_path, filename, NULL);
-        g_free (filename);
-      }
-      else if (g_str_has_suffix (name, PHOTO_NAME_SUFFIX))
-      {
-        target_filename = g_build_filename (photo_path, name, NULL);
-      }
-      else
-      {
-        continue;
-      }
-
-      source_filename = g_build_filename (path_from_before_224, name, NULL);
-      source          = g_file_new_for_path (source_filename);
-      target          = g_file_new_for_path (target_filename);
-      g_print ("copying %s to %s\n", source_filename, target_filename);
-      g_file_move (source, target, G_FILE_COPY_OVERWRITE, NULL, NULL, NULL, NULL);
-      g_free (source_filename);
-      g_free (target_filename);
-      g_object_unref (source);
-      g_object_unref (target);
-    }
-
-    g_dir_close (dir_from_before_224);
-
-    dir = g_file_new_for_path (path_from_before_224);
-    g_file_delete (dir, NULL, NULL);
-    g_object_unref (dir);
-  }
-  g_free (path_from_before_224);
-  g_object_unref (fileutil);
-}
-
 int
 main (int argc, char **argv)
 {
@@ -159,19 +93,15 @@ main (int argc, char **argv)
   GError         *error = NULL;
 
   GOptionEntry options[] = {
-    {"verbose",    'v', 0, G_OPTION_ARG_NONE, &CheeseOptions.verbose,
+    {"verbose",    'v', 0,                    G_OPTION_ARG_NONE,   &CheeseOptions.verbose,
      _("Be verbose"), NULL},
-    {"wide",       'w', 0, G_OPTION_ARG_NONE, &CheeseOptions.wide_mode,
+    {"wide",       'w', 0,                    G_OPTION_ARG_NONE,   &CheeseOptions.wide_mode,
      _("Enable wide mode"), NULL},
-    {"hal-device", 'd', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, &CheeseOptions.hal_device_id,
-     NULL, NULL},
-    {"version", 0, 0, G_OPTION_ARG_NONE,   &CheeseOptions.version,
+    {"version",    0,   0,                    G_OPTION_ARG_NONE,   &CheeseOptions.version,
      _("output version information and exit"), NULL},
     {NULL}
   };
 
-  CheeseOptions.hal_device_id = NULL;
-
   bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALEDIR);
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
@@ -181,6 +111,10 @@ main (int argc, char **argv)
   g_thread_init (NULL);
   gdk_threads_init ();
 
+  /* initialize rsvg */
+  /* needed to load the camera icon for the countdown widget */
+  rsvg_init ();
+
   g_set_application_name (_("Cheese"));
 
   context = g_option_context_new (N_("- Take photos and videos with your webcam, with fun graphical effects"));
@@ -218,12 +152,23 @@ main (int argc, char **argv)
   gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                      APPNAME_DATA_DIR G_DIR_SEPARATOR_S "icons");
 
-  cheese_handle_files_from_before_224 ();
-  cheese_window_init (CheeseOptions.hal_device_id, dbus_server, CheeseOptions.wide_mode);
+  CheeseWindow *window = g_object_new (CHEESE_TYPE_WINDOW,
+                                       "startup-wide", CheeseOptions.wide_mode,
+                                       NULL);
+
+  cheese_dbus_set_window (window);
+
+  gtk_widget_show (GTK_WIDGET (window));
 
   gdk_threads_enter ();
   gtk_main ();
   gdk_threads_leave ();
 
+  /* cleanup rsvg */
+  /* Note: this function is bad with multithread applications as it
+   * calls xmlCleanupParser() and should be only called right before
+   * exit */
+  rsvg_term ();
+
   return 0;
 }
